diff Implab/Components/IInitializable.cs @ 205:8200ab154c8a v2

Added ResetState to RunnableComponent to reset in case of failure Added StateChanged event to IRunnable Renamed Promise.SUCCESS -> Promise.Success Added Promise.FromException Renamed Bundle -> PromiseAll in PromiseExtensions
author cin
date Tue, 25 Oct 2016 17:40:33 +0300
parents d6a8cba73acc
children 9f63dade3a40
line wrap: on
line diff
--- a/Implab/Components/IInitializable.cs	Tue Oct 18 17:49:54 2016 +0300
+++ b/Implab/Components/IInitializable.cs	Tue Oct 25 17:40:33 2016 +0300
@@ -3,8 +3,8 @@
 namespace Implab.Components {
     /// <summary>
     /// Initializable components are created and initialized in two steps, first we have create the component,
     /// then we have to complete it's creation by calling an <see cref="Init()"/> method. All parameters needed
     /// to complete the initialization must be passed before the calling <see cref="Init()"/>
     /// </summary>
     public interface IInitializable {
         /// <summary>
@@ -12,10 +12,10 @@
         /// </summary>
         /// <remarks>
         /// Normally virtual methods shouldn't be called from the constructor, due to the incomplete object state, but
-        /// they can be called from this method. This method is also usefull when we constructing a complex grpah
+        /// they can be called from this method. This method is aьуерщlso usefull when we constructing a complex grpah
         /// of components where cyclic references may take place.
         /// </remarks>
-        void Init();
+        void Initialize();
     }
 }
@@ -3,8 +3,8 @@
     /// <summary>
     /// Initializable components are created and initialized in two steps, first we have create the component,
-    /// then we have to complete it's creation by calling an <see cref="Init()"/> method. All parameters needed
-    /// to complete the initialization must be passed before the calling <see cref="Init()"/>
+    /// then we have to complete it's creation by calling an <see cref="Initialize()"/> method. All parameters needed
+    /// to complete the initialization must be passed before the calling <see cref="Initialize()"/>
     /// </summary>
     public interface IInitializable {